Python bindings to the OpenStack Trove API
==========================================

.. image:: https://governance.openstack.org/tc/badges/python-troveclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. image:: https://img.shields.io/pypi/v/python-troveclient.svg
    :target: https://pypi.org/project/python-troveclient/
    :alt: Latest Version

This is a client for the OpenStack Trove API. There's a Python API (the
``troveclient`` module), and a command-line script (``trove``). Each
implements 100% of the OpenStack Trove API.

See the `Trove CLI Guide`_ for information on how to use the ``trove``
command-line tool. You may also want to look at the
`OpenStack API documentation`_.

.. _Trove CLI Guide: https://docs.openstack.org/trove/latest/cli
.. _OpenStack API documentation: https://docs.openstack.org/api-quick-start/

python-troveclient is licensed under the Apache License like the rest of OpenStack.

* License: Apache License, Version 2.0
* `Online Documentation`_
* `Bugs`_ - issue tracking
* `PyPi`_- package installation
* `Blueprints`_ - feature specifications
* `Git Source`_
* `Specs`_
* `How to Contribute`_
* `Release Notes`_

.. _Online Documentation: https://docs.openstack.org/python-troveclient/latest
.. _Bugs: https://storyboard.openstack.org/#!/project/openstack/python-troveclient
.. _PyPi: https://pypi.org/project/python-troveclient
.. _Blueprints: https://storyboard.openstack.org/#!/project/openstack/python-troveclient
.. _Git Source: https://opendev.org/openstack/python-troveclient/
.. _Specs: https://specs.openstack.org/openstack/trove-specs/
.. _How to Contribute: https://docs.openstack.org/infra/manual/developers.html
.. _Release Notes: https://docs.openstack.org/releasenotes/python-troveclient
